//
// C++ Interface: CFireEdit
//
// Description: 
//
//
// Author: Harald Krippel <harald@the-develop.net>, (C) 2007
//
// Copyright: See COPYING file that comes with this distribution
//
//

#ifndef CFIREEDITDLG_H
#define CFIREEDITDLG_H

/**
  *@author Krippel Harald
  */

#include <QDialog>
#include <QString>
#include <QPixmap>

#include "ui_firedlg4.h"
#include "CQcakeDlg.hpp"
#include "listviews.hpp"

class CFireEditDlg: public CQcakeDlg
{
    Q_OBJECT
      
public:
    CFireEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
    ~CFireEditDlg();

public slots:
    virtual void slotGetData();
    virtual void slotGetData(FolderListItem *i);
    virtual void slotEditData();
    virtual void slotEditColor();

 
private slots:
 
protected:
    Ui::FireEditDlg ui;    
    FolderListItem *point;
    QColor mycolor;
    
private:
    QWidget *myParent;
};
#endif
